diff layer/Layer.h @ 335:2f83b6e3b8ca

* Add Erase tool and mode * Add icons for Normalize buttons in property boxes, and for Show Peaks * Add support for velocity in notes -- not yet reflected in display or editable in the note edit dialog, but they are imported from MIDI, played, and exported * Begin work on making pastes align pasted times (subtler than I thought)
author Chris Cannam
date Fri, 23 Nov 2007 16:48:23 +0000
parents 984c1975f1ff
children 020c485aa7e0 0895517bb2d1
line wrap: on
line diff
--- a/layer/Layer.h	Thu Nov 22 14:27:41 2007 +0000
+++ b/layer/Layer.h	Fri Nov 23 16:48:23 2007 +0000
@@ -151,7 +151,7 @@
 	return false;
     }
 
     // Draw and edit modes:
     //
     // Layer needs to get actual mouse events, I guess.  Draw mode is
     // probably the easier.
@@ -160,6 +160,10 @@
     virtual void drawDrag(View *, QMouseEvent *) { }
     virtual void drawEnd(View *, QMouseEvent *) { }
 
+    virtual void eraseStart(View *, QMouseEvent *) { }
+    virtual void eraseDrag(View *, QMouseEvent *) { }
+    virtual void eraseEnd(View *, QMouseEvent *) { }
+
     virtual void editStart(View *, QMouseEvent *) { }
     virtual void editDrag(View *, QMouseEvent *) { }
     virtual void editEnd(View *, QMouseEvent *) { }
@@ -151,7 +151,7 @@
     }
 
-    // Draw and edit modes:
+    // Draw, erase, and edit modes:
     //
     // Layer needs to get actual mouse events, I guess.  Draw mode is